@@ -355,7 +355,7 @@ void calculate_event_values(duo **eventbins, long *eventbinnum, MYREAL eventinte
     if(bin>=eventbinnum[pop])
       {
         allocsize = bin+1;
-        eventbins[pop] = myrealloc(eventbins[pop], allocsize * sizeof(duo));
+        eventbins[pop] = (duo *) myrealloc(eventbins[pop], allocsize * sizeof(duo));
         //	  fprintf(stdout,"%i> ral: as=%li, old=%li, last val=(%f,%f)\n",myID,allocsize, eventbinnum[pop],
         //  eventbins[pop][eventbinnum[pop]-1][0],eventbins[pop][eventbinnum[pop]-1][1]);
         for(i=eventbinnum[pop];i < allocsize; i++)
@@ -515,7 +515,7 @@ void read_event_values_fromfile(FILE *file, world_fmt *world)
 	  if(allocsize[spacer + pop] < eventbinnum[pop])
 	    {
 	      allocsize[spacer + pop] += SOME_ELEMENTS;
-	      eventbins[pop] = myrealloc(eventbins[pop],allocsize[spacer + pop] * sizeof(duo));
+	      eventbins[pop] = (duo *) myrealloc(eventbins[pop],allocsize[spacer + pop] * sizeof(duo));
 	    }
 	  eventbins[pop][i][0] = atof(strsep(&inptr,"\t"));
 	  eventbins[pop][i][1] = atof(strsep(&inptr,"\t"));
