@@ -9,13 +9,17 @@ extern "C" {
   void set_haru_handler(void);
 }
 extern int throw_new_handler(size_t t);
-void set_haru_handler() {
+
+void set_haru_handler(void) 
+{
   _set_new_handler(throw_new_handler);
 }
 #endif
 
 int dummy_function(int do_nothing)
 {
-  print("Some computer fail to compile MIGRATE with empty files\n");
-  return 0;
+  int x;
+  //Some computer fail to compile MIGRATE with empty files
+  x = do_nothing;
+  return x;
 }
